// Software for Inference and Robotic Mapping with the Arak Process
// Copyright (C) 2005 Mark A. Paskin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
// Author contact information:
//   Mark A. Paskin
//   http://paskin.org
//   mark@paskin.org

#include "jet.hpp"

const unsigned char Arak::jet_rgb[64][3] = {
  {0,      0,    144},
  {0,      0,    160},
  {0,      0,    176},
  {0,      0,    192},
  {0,      0,    208},
  {0,      0,    224},
  {0,      0,    240},
  {0,      0,    255},
  {0,     16,    255},
  {0,     32,    255},
  {0,     48,    255},
  {0,     64,    255},
  {0,     80,    255},
  {0,     96,    255},
  {0,    112,    255},
  {0,    128,    255},
  {0,    144,    255},
  {0,    160,    255},
  {0,    176,    255},
  {0,    192,    255},
  {0,    208,    255},
  {0,    224,    255},
  {0,    240,    255},
  {0,    255,    255},
  { 16,    255,    240},
  { 32,    255,    224},
  { 48,    255,    208},
  { 64,    255,    192},
  { 80,    255,    176},
  { 96,    255,    160},
  {112,    255,    144},
  {128,    255,    128},
  {144,    255,    112},
  {160,    255,     96},
  {176,    255,     80},
  {192,    255,     64},
  {208,    255,     48},
  {224,    255,     32},
  {240,    255,     16},
  {255,    255,      0},
  {255,    240,      0},
  {255,    224,      0},
  {255,    208,      0},
  {255,    192,      0},
  {255,    176,      0},
  {255,    160,      0},
  {255,    144,      0},
  {255,    128,      0},
  {255,    112,      0},
  {255,     96,      0},
  {255,     80,      0},
  {255,     64,      0},
  {255,     48,      0},
  {255,     32,      0},
  {255,     16,      0},
  {255,      0,      0},
  {240,      0,      0},
  {224,      0,      0},
  {208,      0,      0},
  {192,      0,      0},
  {176,      0,      0},
  {160,      0,      0},
  {144,      0,      0},
  {128,      0,      0}
};

const CGAL::Color Arak::jet_colors[64] = {
  CGAL::Color(0,      0,    144),
  CGAL::Color(0,      0,    160),
  CGAL::Color(0,      0,    176),
  CGAL::Color(0,      0,    192),
  CGAL::Color(0,      0,    208),
  CGAL::Color(0,      0,    224),
  CGAL::Color(0,      0,    240),
  CGAL::Color(0,      0,    255),
  CGAL::Color(0,     16,    255),
  CGAL::Color(0,     32,    255),
  CGAL::Color(0,     48,    255),
  CGAL::Color(0,     64,    255),
  CGAL::Color(0,     80,    255),
  CGAL::Color(0,     96,    255),
  CGAL::Color(0,    112,    255),
  CGAL::Color(0,    128,    255),
  CGAL::Color(0,    144,    255),
  CGAL::Color(0,    160,    255),
  CGAL::Color(0,    176,    255),
  CGAL::Color(0,    192,    255),
  CGAL::Color(0,    208,    255),
  CGAL::Color(0,    224,    255),
  CGAL::Color(0,    240,    255),
  CGAL::Color(0,    255,    255),
  CGAL::Color( 16,    255,    240),
  CGAL::Color( 32,    255,    224),
  CGAL::Color( 48,    255,    208),
  CGAL::Color( 64,    255,    192),
  CGAL::Color( 80,    255,    176),
  CGAL::Color( 96,    255,    160),
  CGAL::Color(112,    255,    144),
  CGAL::Color(128,    255,    128),
  CGAL::Color(144,    255,    112),
  CGAL::Color(160,    255,     96),
  CGAL::Color(176,    255,     80),
  CGAL::Color(192,    255,     64),
  CGAL::Color(208,    255,     48),
  CGAL::Color(224,    255,     32),
  CGAL::Color(240,    255,     16),
  CGAL::Color(255,    255,      0),
  CGAL::Color(255,    240,      0),
  CGAL::Color(255,    224,      0),
  CGAL::Color(255,    208,      0),
  CGAL::Color(255,    192,      0),
  CGAL::Color(255,    176,      0),
  CGAL::Color(255,    160,      0),
  CGAL::Color(255,    144,      0),
  CGAL::Color(255,    128,      0),
  CGAL::Color(255,    112,      0),
  CGAL::Color(255,     96,      0),
  CGAL::Color(255,     80,      0),
  CGAL::Color(255,     64,      0),
  CGAL::Color(255,     48,      0),
  CGAL::Color(255,     32,      0),
  CGAL::Color(255,     16,      0),
  CGAL::Color(255,      0,      0),
  CGAL::Color(240,      0,      0),
  CGAL::Color(224,      0,      0),
  CGAL::Color(208,      0,      0),
  CGAL::Color(192,      0,      0),
  CGAL::Color(176,      0,      0),
  CGAL::Color(160,      0,      0),
  CGAL::Color(144,      0,      0),
  CGAL::Color(128,      0,      0)
};
